# Changelog

## [0.1.1] - 2026-03-03

### Added
- 迁移项目管理到 `uv`，使用 `pyproject.toml` 替代 `setup.py`。
- 命令行工具支持表格化输出 (使用 `tabulate` 和 `wcwidth`)。
- 增加 `pytest` 测试框架及初步冒烟测试。

## 2025-05-24

- 主分支从 `master` 改为 `main`

## [0.0.9] - 2024-04-11

### Changed

- Removed specific versions for pandas and requests dependencies

## [0.0.8] - 2024-03-26

### Added

- 增加了分省/城市查询功能
